@@ -18,7 +18,7 @@ from .reference import set_reference_func
 from .baseline import baseline_func
 from .epochs import epoch_func, drop_bad_epochs_func
 from .bad_chs import mark_bad_chs, interp_bad_chs
-from .check_channel_types import check_for_ch_type
+from .check_channel_types_1 import check_for_ch_type
 from .ica import generate_ica, fit_ica_no_autoreject, fit_ica_with_autoreject, reject_eog_eeg_comps, apply_ica
 
 from .pipeline_dicts import get_preset_pipeline
